@@ -95,8 +95,7 @@ proc ::mbtools::utils::warmup { steps times args } {
 
 	# Set the new forcecap into espresso and integrate
 	# catch tabulated force cap error in case tabulated option is not turned on
-	catch {inter tabforcecap $cap}
-	inter ljforcecap $cap
+	inter forcecap $cap
 	integrate $steps
 	set cap [expr $cap + $capincr ]
 	::mmsg::send [namespace current]  "run $i of $times at time=[setmd time] (cap=$cap) " 
@@ -107,8 +106,7 @@ proc ::mbtools::utils::warmup { steps times args } {
     
     # Turn off all forcecapping
     ::mmsg::send [namespace current] "uncapping forces"
-    catch {inter tabforcecap 0}
-    inter ljforcecap 0
+    inter forcecap 0
  }
 
 
