@@ -1,7 +1,3 @@
-#!/bin/sh
-# tricking... the line after a these comments are interpreted as standard shell script \
-    exec $ESPRESSO_SOURCE/Espresso $0 $*
-#
 # Copyright (C) 2010,2012,2013 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #   Max-Planck-Institute for Polymer Research, Theory Group
@@ -119,16 +115,16 @@ integrate 0
 set act_min_dist [analyze mindist]
 
 set cap 20
-inter ljforcecap $cap
+inter forcecap $cap
 set i 0
 while { $i < $warm_n_times && ( $act_min_dist < $min_dist || $i < $warm_n_min ) } {
     integrate $warm_steps
     set act_min_dist [analyze mindist]
     set cap [expr $cap+10]
-    inter ljforcecap $cap
+    inter forcecap $cap
     incr i
 }
-inter ljforcecap 0
+inter forcecap 0
 
 # maggs requires domain decompostion with no verlet lists
 cellsystem domain_decomposition -no_verlet_list
