@@ -124,6 +124,11 @@ extern const char* ESPRESSO_VERSION;
 #define SHAKE_MAX_ITERATIONS 1000
 #endif
 
+/** maximal number of objects in the object-in-fluid framework. */
+#ifndef MAX_OBJECTS_IN_FLUID
+#define MAX_OBJECTS_IN_FLUID 10000
+#endif
+
 /* Mathematical constants, from gcc's math.h */
 #ifndef M_PI
 #define M_E		2.7182818284590452353602874713526625L  /* e */
