@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2012 The ESPResSo project
+  Copyright (C) 2010,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -174,13 +174,6 @@ extern int check_id;
 #define MDLC_TRACE(cmd)
 #endif
 
-#ifdef EWALD_DEBUG
-#define EWALD_TRACE(cmd) { cmd;  }
-#else
-/** Equals { cmd } if EWALD_DEBUG is set. */
-#define EWALD_TRACE(cmd)
-#endif
-
 #ifdef MAGGS_DEBUG
 #define MAGGS_TRACE(cmd) { cmd;  }
 #else
