@@ -109,7 +109,7 @@ static double calc_pwdist(Particle *p1, Bonded_ia_parameters *iaparams, int *clc
     }
   }
   /*
-  if (distwallmin <= distmx) {
+    if (distwallmin <= iaparams->p.endangledist.distmax) {
     fprintf(stdout,"  clconstr=%d  distwallmin=%f  distmx=%f\n",*clconstr,distwallmin,distmx);
   }
   */
