@@ -35,9 +35,11 @@
 #include "ljgen.h"
 #include "steppot.h"
 #include "hertzian.h"
+#include "gaussian.h"
 #include "bmhtf-nacl.h"
 #include "buckingham.h"
 #include "soft_sphere.h"
+#include "hat.h"
 #include "ljcos.h"
 #include "ljcos2.h"
 #include "ljangle.h"
@@ -45,9 +47,17 @@
 #include "overlap.h"
 #include "gb.h"
 #include "fene.h"
+#include "object-in-fluid/stretching_force.h"
+#include "object-in-fluid/area_force_local.h"
+#include "object-in-fluid/area_force_global.h"
+#include "object-in-fluid/bending_force.h"
+#include "object-in-fluid/volume_force.h"
 #include "harmonic.h"
 #include "subt_lj.h"
 #include "angle.h"
+#include "angle_harmonic.h"
+#include "angle_cosine.h"
+#include "angle_cossquare.h"
 #include "angledist.h"
 #include "dihedral.h"
 #include "debye_hueckel.h"
@@ -130,6 +140,11 @@ MDINLINE double calc_non_bonded_pair_energy(Particle *p1, Particle *p2,
   ret += hertzian_pair_energy(p1,p2,ia_params,d,dist,dist2);
 #endif
 
+#ifdef GAUSSIAN
+  /* Gaussian potential */
+  ret += gaussian_pair_energy(p1,p2,ia_params,d,dist,dist2);
+#endif
+
 #ifdef BMHTF_NACL
   /* BMHTF NaCl */
   ret += BMHTF_pair_energy(p1,p2,ia_params,d,dist,dist2);
@@ -150,6 +165,11 @@ MDINLINE double calc_non_bonded_pair_energy(Particle *p1, Particle *p2,
   ret  += soft_pair_energy(p1,p2,ia_params,d,dist);
 #endif
 
+#ifdef HAT
+  /* hat */
+  ret  += hat_pair_energy(p1,p2,ia_params,d,dist);
+#endif
+
 #ifdef LJCOS2
   /* lennard jones */
   ret += ljcos2_pair_energy(p1,p2,ia_params,d,dist);
@@ -315,9 +335,21 @@ MDINLINE void add_bonded_energy(Particle *p1)
       bond_broken = subt_lj_pair_energy(p1, p2, iaparams, dx, &ret);
       break;
 #endif
-#ifdef BOND_ANGLE
-    case BONDED_IA_ANGLE:
+#ifdef BOND_ANGLE_OLD
+    /* the first case is not needed and should not be called */ 
+    case BONDED_IA_ANGLE_OLD:
       bond_broken = angle_energy(p1, p2, p3, iaparams, &ret);
+      break; 
+#endif
+#ifdef BOND_ANGLE
+    case BONDED_IA_ANGLE_HARMONIC:
+      bond_broken = angle_harmonic_energy(p1, p2, p3, iaparams, &ret);
+      break;
+    case BONDED_IA_ANGLE_COSINE:
+      bond_broken = angle_cosine_energy(p1, p2, p3, iaparams, &ret);
+      break;
+    case BONDED_IA_ANGLE_COSSQUARE:
+      bond_broken = angle_cossquare_energy(p1, p2, p3, iaparams, &ret);
       break;
 #endif
 #ifdef BOND_ANGLEDIST
@@ -389,14 +421,29 @@ MDINLINE void add_bonded_energy(Particle *p1)
       return;
     }
 
-    switch (n_partners) {
-    case 1:
-      if (bond_broken) {
+    if (bond_broken) {
+      switch (n_partners) {
+      case 1: {
 	char *errtext = runtime_error(128 + 2*ES_INTEGER_SPACE);
-	ERROR_SPRINTF(errtext,"{076 bond broken between particles %d, %d, %d and %d} ",
-		p1->p.identity, p2->p.identity, p3->p.identity, p4->p.identity); 
-	continue;
+	ERROR_SPRINTF(errtext,"{083 bond broken between particles %d and %d} ",
+		      p1->p.identity, p2->p.identity); 
+	break;
       }
+      case 2: {
+	char *errtext = runtime_error(128 + 3*ES_INTEGER_SPACE);
+	ERROR_SPRINTF(errtext,"{084 bond broken between particles %d, %d and %d} ",
+		      p1->p.identity, p2->p.identity, p3->p.identity); 
+	break;
+      }
+      case 3: {
+	char *errtext = runtime_error(128 + 4*ES_INTEGER_SPACE);
+	ERROR_SPRINTF(errtext,"{085 bond broken between particles %d, %d, %d and %d} ",
+		      p1->p.identity, p2->p.identity, p3->p.identity, p4->p.identity); 
+	break;
+      }
+      }
+      // bond broken, don't add whatever we find in the energy
+      continue;
     }
 
     *obsstat_bonded(&energy, type_num) += ret;
@@ -416,6 +463,10 @@ MDINLINE void add_kinetic_energy(Particle *p1)
   energy.data.e[0] += (SQR(p1->m.v[0]) + SQR(p1->m.v[1]) + SQR(p1->m.v[2]))*PMASS(*p1);
 
 #ifdef ROTATION
+#ifdef ROTATION_PER_PARTICLE
+if (p1->p.rotation)
+#endif
+{
 #ifdef ROTATIONAL_INERTIA
   /* the rotational part is added to the total kinetic energy;
      Here we use the rotational inertia  */
@@ -428,6 +479,7 @@ MDINLINE void add_kinetic_energy(Particle *p1)
      at the moment, we assume unit inertia tensor I=(1,1,1)  */
   energy.data.e[0] += (SQR(p1->m.omega[0]) + SQR(p1->m.omega[1]) + SQR(p1->m.omega[2]))*time_step*time_step;
 #endif
+}
 #endif	
 }
 
