@@ -42,8 +42,10 @@
 #include "ljangle.h"
 #include "steppot.h"
 #include "hertzian.h"
+#include "gaussian.h"
 #include "buckingham.h"
 #include "soft_sphere.h"
+#include "hat.h"
 #include "tab.h"
 #include "overlap.h"
 #include "ljcos.h"
@@ -218,6 +220,12 @@ void initialize_ia_params(IA_parameters *params) {
   params->Hertzian_sig = INACTIVE_CUTOFF;
 #endif
 
+#ifdef GAUSSIAN
+  params->Gaussian_eps = 0.0;
+  params->Gaussian_sig = 1.0;
+  params->Gaussian_cut = INACTIVE_CUTOFF;
+#endif
+
 #ifdef BMHTF_NACL
   params->BMHTF_A =
     params->BMHTF_B =
@@ -257,6 +265,11 @@ void initialize_ia_params(IA_parameters *params) {
   params->soft_cut = INACTIVE_CUTOFF;
 #endif
 
+#ifdef HAT
+  params->HAT_Fmax =
+    params->HAT_r = 0.0;
+#endif
+
 #ifdef LJCOS
   params->LJCOS_eps =
     params->LJCOS_sig =
@@ -352,6 +365,10 @@ void initialize_ia_params(IA_parameters *params) {
   params->mol_cut_type = 0;
   params->mol_cut_cutoff = 0.0;
 #endif
+
+#ifdef CATALYTIC_REACTIONS
+  params->REACTION_range = 0.0;
+#endif
 }
 
 /** Copy interaction parameters. */
@@ -536,6 +553,7 @@ static void recalc_global_maximal_nonbonded_cutoff()
       max_cut_global = dpd_tr_cut;
   }
 #endif
+
 }
 
 static void recalc_maximal_cutoff_nonbonded()
@@ -590,6 +608,11 @@ static void recalc_maximal_cutoff_nonbonded()
 	max_cut_current = data->Hertzian_sig;
 #endif
 
+#ifdef GAUSSIAN
+      if (max_cut_current < data->Gaussian_cut)
+	max_cut_current = data->Gaussian_cut;
+#endif
+
 #ifdef BMHTF_NACL
       if (max_cut_current < data->BMHTF_cut)
 	max_cut_current = data->BMHTF_cut;
@@ -610,6 +633,11 @@ static void recalc_maximal_cutoff_nonbonded()
 	max_cut_current = data->soft_cut;
 #endif
 
+#ifdef HAT
+      if (max_cut_current < data->HAT_r)
+	max_cut_current = data->HAT_r;
+#endif
+
 #ifdef LJCOS
       {
 	double max_cut_tmp = data->LJCOS_cut + data->LJCOS_offset;
@@ -646,6 +674,19 @@ static void recalc_maximal_cutoff_nonbonded()
 	max_cut_current = data->TUNABLE_SLIP_r_cut;
 #endif
 
+#ifdef CATALYTIC_REACTIONS
+      if (max_cut_current < data->REACTION_range)
+	max_cut_current = data->REACTION_range;
+#endif
+
+#ifdef MOL_CUT
+      if (data->mol_cut_type != 0) {
+	if (max_cut_current < data->mol_cut_cutoff)
+	  max_cut_current = data->mol_cut_cutoff;
+	max_cut_current += 2.0* max_cut_bonded;
+      }
+#endif
+
       IA_parameters *data_sym = get_ia_param(j, i);
 
       /* no interaction ever touched it, at least no real
@@ -657,10 +698,6 @@ static void recalc_maximal_cutoff_nonbonded()
       if (max_cut_global > max_cut_current)
 	max_cut_current = max_cut_global;
 
-#if defined(MOL_CUT) && !defined(ONE_PROC_ADRESS)
-      max_cut_current += 2.0* max_cut_bonded;
-#endif
-
       data_sym->max_cut =
 	data->max_cut = max_cut_current;
 
@@ -689,8 +726,14 @@ char *get_name_of_bonded_ia(int i) {
   switch (i) {
   case BONDED_IA_FENE:
     return "FENE";
-  case BONDED_IA_ANGLE:
+  case BONDED_IA_ANGLE_OLD:
     return "angle";
+  case BONDED_IA_ANGLE_HARMONIC:
+    return "angle_harmonic";
+  case BONDED_IA_ANGLE_COSINE:
+    return "angle_cosine";
+  case BONDED_IA_ANGLE_COSSQUARE:
+    return "angle_cossquare";
   case BONDED_IA_ANGLEDIST:
     return "angledist";
   case BONDED_IA_DIHEDRAL:
@@ -709,6 +752,16 @@ char *get_name_of_bonded_ia(int i) {
     return "RIGID_BOND";
   case BONDED_IA_VIRTUAL_BOND:
     return "VIRTUAL_BOND";
+  case BONDED_IA_STRETCHING_FORCE:
+    return "STRETCHING_FORCE";
+  case BONDED_IA_AREA_FORCE_LOCAL:
+    return "AREA_FORCE_LOCAL";
+  case BONDED_IA_AREA_FORCE_GLOBAL:
+    return "AREA_FORCE_GLOBAL";
+  case BONDED_IA_BENDING_FORCE:
+    return "BENDING_FORCE";
+  case BONDED_IA_VOLUME_FORCE:
+    return "VOLUME_FORCE";
   default:
     fprintf(stderr, "%d: INTERNAL ERROR: name of unknown interaction %d requested\n",
 	    this_node, i);
