@@ -44,6 +44,8 @@
 #include "particle_data.h"
 #include "mol_cut.h"
 #include "grid.h"
+#include "forcecap.h"
+
 
 #ifdef LJ_ANGLE
 #include <math.h>
@@ -51,13 +53,7 @@
 /** For the warmup you can cap the singularity of the directionnal LJ
     potential at r=0. look into the warmup documentation for more
     details (who wants to write that?).*/
-extern double ljangle_force_cap;
-
-/** set the force cap for the directional LJ interaction.
-    @param ljangleforcecap the maximal force, 0 to disable, -1 for individual cutoff
-    for each of the interactions.
-*/
-int ljangleforcecap_set_params(double ljangleforcecap);
+    /* replaced by global force_cap -- to be removed */
 
 int ljangle_set_params(int part_type_a, int part_type_b,
 				double eps, double sig, double cut,
@@ -385,9 +381,9 @@ MDINLINE double ljangle_pair_energy(Particle *p1, Particle *p2, IA_parameters *i
 }
 
 
-/** calculate ljangle_capradius from ljangle_force_cap */
+/** calculate ljangle_capradius from force_cap */
 /* This routine does not take the optional 2nd environment into account. */
-void calc_ljangle_cap_radii(double force_cap);
+void calc_ljangle_cap_radii();
 
 
 #endif /* ifdef LJ_ANGLE */
