@@ -27,16 +27,6 @@
 
 #ifdef MORSE
 
-double morse_force_cap = 0.0;
-
-int morseforcecap_set_params(double morseforcecap)
-{
-  if (morse_force_cap != -1.0)
-    mpi_morse_cap_forces(morse_force_cap);
-  
-  return ES_OK;
-}
-
 int morse_set_params(int part_type_a, int part_type_b,
 		     double eps, double alpha,
 		     double rmin, double cut, double cap_radius)
@@ -63,49 +53,50 @@ int morse_set_params(int part_type_a, int part_type_b,
   /* broadcast interaction parameters */
   mpi_bcast_ia_params(part_type_a, part_type_b);
 
-  if (morse_force_cap != -1.0)
-    mpi_morse_cap_forces(morse_force_cap);
+  mpi_cap_forces(force_cap);
 
   return ES_OK;
 }
 
-void calc_morse_cap_radii(double force_cap)
+void calc_morse_cap_radii()
 {
-  int i,j,cnt=0;
-  IA_parameters *params;
-  double force=0.0, rad=0.0, step, add1, add2;
+  /* do not compute cap radii if force capping is "individual" */
+  if( force_cap != -1.0){
+    int i,j,cnt=0;
+    IA_parameters *params;
+    double force=0.0, rad=0.0, step, add1, add2;
 
-  for(i=0; i<n_particle_types; i++) {
-    for(j=0; j<n_particle_types; j++) {
-      params = get_ia_param(i,j);
-      if(force_cap > 0.0 && params->MORSE_eps > 0.0) {
+    for(i=0; i<n_particle_types; i++) {
+      for(j=0; j<n_particle_types; j++) {
+        params = get_ia_param(i,j);
+        if(force_cap > 0.0 && params->MORSE_eps > 0.0) {
 
-	/* I think we have to solve this numerically... and very crude as well */
+    /* I think we have to solve this numerically... and very crude as well */
 
-	cnt=0;
-	rad = params->MORSE_rmin - 0.69314719 / params->MORSE_alpha;
-	step = -0.1 * rad;
-	force=0.0;
-	
-	while(step != 0) {
+    cnt=0;
+    rad = params->MORSE_rmin - 0.69314719 / params->MORSE_alpha;
+    step = -0.1 * rad;
+    force=0.0;
+    
+    while(step != 0) {
+      add1 = exp(-2.0 * params->MORSE_alpha * (rad - params->MORSE_rmin));
+      add2 = exp( -params->MORSE_alpha * (rad - params->MORSE_rmin));
+      force   = -params->MORSE_eps * 2.0 * params->MORSE_alpha * (add2 - add1) / rad;
 
-          add1 = exp(-2.0 * params->MORSE_alpha * (rad - params->MORSE_rmin));
-          add2 = exp( -params->MORSE_alpha * (rad - params->MORSE_rmin));
-          force   = -params->MORSE_eps * 2.0 * params->MORSE_alpha * (add2 - add1) / rad;
-
-	  if((step < 0 && force_cap < force) || (step > 0 && force_cap > force)) {
-	    step = - (step/2.0); 
-	  }
-	  if(fabs(force-force_cap) < 1.0e-6) step=0;
-	  rad += step; cnt++;
-	} 
-      	params->MORSE_capradius = rad;
+      if((step < 0 && force_cap < force) || (step > 0 && force_cap > force)) {
+        step = - (step/2.0); 
       }
-      else {
-	params->MORSE_capradius = 0.0; 
+      if(fabs(force-force_cap) < 1.0e-6) step=0;
+      rad += step; cnt++;
+    } 
+          params->MORSE_capradius = rad;
+        }
+        else {
+    params->MORSE_capradius = 0.0; 
+        }
+        FORCE_TRACE(fprintf(stderr,"%d: Ptypes %d-%d have cap_radius %f and cap_force %f (iterations: %d)\n",
+          this_node,i,j,rad,force,cnt));
       }
-      FORCE_TRACE(fprintf(stderr,"%d: Ptypes %d-%d have cap_radius %f and cap_force %f (iterations: %d)\n",
-			  this_node,i,j,rad,force,cnt));
     }
   }
 }
