@@ -18,8 +18,8 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>. 
 */
-#ifndef ANGLE_TCL_H
-#define ANGLE_TCL_H
+#ifndef _ANGLE_TCL_H
+#define _ANGLE_TCL_H
 /** \file angle_tcl.h
  * Tcl interface for \ref angle.h
  */
@@ -27,7 +27,7 @@
 #include "parser.h"
 #include "interaction_data.h"
 
-#ifdef BOND_ANGLE
+#ifdef BOND_ANGLE_OLD
 
 /// parse parameters for the angle potential
 int tclcommand_inter_parse_angle(Tcl_Interp *interp, int bond_type, int argc, char **argv);
