@@ -28,6 +28,7 @@
 #include "constraint_tcl.h"
 #include "domain_decomposition_tcl.h"
 #include "dpd_tcl.h"
+#include "galilei_tcl.h"
 #include "global_tcl.h"
 #include "grid_tcl.h"
 #include "iccp3m_tcl.h"
@@ -42,6 +43,7 @@
 #include "polymer_tcl.h"
 #include "pressure_tcl.h"
 #include "random_tcl.h"
+#include "reaction_tcl.h"
 #include "statistics_chain_tcl.h"
 #include "statistics_cluster_tcl.h"
 #include "statistics_correlation_tcl.h"
@@ -50,6 +52,7 @@
 #include "statistics_tcl.h"
 #include "thermostat_tcl.h"
 #include "virtual_sites_com_tcl.h"
+#include "ghmc_tcl.h"
 
 #ifdef TK
 #include <tk.h>
@@ -101,7 +104,6 @@ int tclcommand_uwerr(ClientData data, Tcl_Interp *interp, int argc, char *argv[]
 /** callback for \ref timing_samples. See \ref tuning_tcl.c */
 int tclcallback_timings(Tcl_Interp *interp, void *data);
 
-
 /// from \ref scriptsdir.c
 char *get_default_scriptsdir();
 
@@ -159,6 +161,10 @@ static void register_tcl_commands(Tcl_Interp* interp) {
   REGISTER_COMMAND("thermostat", tclcommand_thermostat);
   /* in bin.c */
   REGISTER_COMMAND("bin", tclcommand_bin);
+  /* in ghmc.c */
+  REGISTER_COMMAND("ghmc", tclcommand_ghmc);
+  REGISTER_COMMAND("save_state", tclcommand_save_state);
+  REGISTER_COMMAND("load_state", tclcommand_load_state);
   /* in lb.c */
 
   REGISTER_COMMAND("lbfluid", tclcommand_lbfluid);
@@ -199,6 +205,14 @@ static void register_tcl_commands(Tcl_Interp* interp) {
 #ifdef COLLISION_DETECTION
   REGISTER_COMMAND("on_collision", tclcommand_on_collision);
 #endif
+#ifdef CATALYTIC_REACTIONS
+  REGISTER_COMMAND("reaction", tclcommand_reaction);
+#endif
+  REGISTER_COMMAND("kill_particle_motion", tclcommand_kill_particle_motion);
+  REGISTER_COMMAND("kill_particle_forces", tclcommand_kill_particle_forces);
+  REGISTER_COMMAND("system_CMS", tclcommand_system_CMS);
+  REGISTER_COMMAND("system_CMS_velocity", tclcommand_system_CMS_velocity);
+  REGISTER_COMMAND("galilei_transform", tclcommand_galilei_transform);
 }
 
 static void register_global_variables(Tcl_Interp *interp)
