@@ -43,6 +43,8 @@
 #include "bmhtf-nacl_tcl.h"
 #include "buckingham_tcl.h"
 #include "gb_tcl.h"
+#include "gaussian_tcl.h"
+#include "hat_tcl.h"
 #include "lj_tcl.h"
 #include "ljangle_tcl.h"
 #include "ljcos_tcl.h"
@@ -72,6 +74,9 @@
 
 // bonded
 #include "angle_tcl.h"
+#include "angle_harmonic_tcl.h"
+#include "angle_cosine_tcl.h"
+#include "angle_cossquare_tcl.h"
 #include "angledist_tcl.h"
 #include "dihedral_tcl.h"
 #include "endangledist_tcl.h"
@@ -79,6 +84,11 @@
 #include "overlap_tcl.h"
 #include "harmonic_tcl.h"
 #include "subt_lj_tcl.h"
+#include "tcl/object-in-fluid/area_force_local_tcl.h"
+#include "tcl/object-in-fluid/area_force_global_tcl.h"
+#include "tcl/object-in-fluid/volume_force_tcl.h"
+#include "tcl/object-in-fluid/stretching_force_tcl.h"
+#include "tcl/object-in-fluid/bending_force_tcl.h"
 
 ///
 int tclprint_to_result_CoulombIA(Tcl_Interp *interp);
@@ -283,12 +293,34 @@ int tclprint_to_result_BondedIA(Tcl_Interp *interp, int i)
   switch (params->type) {
   case BONDED_IA_FENE:
     return tclprint_to_result_feneIA(interp, params);
+  case BONDED_IA_STRETCHING_FORCE:						
+    return tclprint_to_result_stretchingforceIA(interp, params);
+  case BONDED_IA_AREA_FORCE_LOCAL:					
+	return tclprint_to_result_areaforcelocalIA(interp, params);
+  case BONDED_IA_BENDING_FORCE:						
+	return tclprint_to_result_bendingforceIA(interp, params);
+#ifdef AREA_FORCE_GLOBAL
+  case BONDED_IA_AREA_FORCE_GLOBAL:						
+	return tclprint_to_result_areaforceglobalIA(interp, params);
+#endif
+#ifdef VOLUME_FORCE
+  case BONDED_IA_VOLUME_FORCE:						
+	return tclprint_to_result_volumeforceIA(interp, params);
+#endif
   case BONDED_IA_HARMONIC:
     return tclprint_to_result_harmonicIA(interp, params);
-#ifdef BOND_ANGLE
-  case BONDED_IA_ANGLE:
+#ifdef BOND_ANGLE_OLD
+  case BONDED_IA_ANGLE_OLD:
     return tclprint_to_result_angleIA(interp, params);
 #endif
+#ifdef BOND_ANGLE
+  case BONDED_IA_ANGLE_HARMONIC:
+    return tclprint_to_result_angle_harmonicIA(interp, params);
+  case BONDED_IA_ANGLE_COSINE:
+    return tclprint_to_result_angle_cosineIA(interp, params);
+  case BONDED_IA_ANGLE_COSSQUARE:
+    return tclprint_to_result_angle_cossquareIA(interp, params);
+#endif
 #ifdef BOND_ANGLEDIST
   case BONDED_IA_ANGLEDIST:
     return tclprint_to_result_angledistIA(interp, params);
@@ -391,6 +423,10 @@ int tclprint_to_result_NonbondedIA(Tcl_Interp *interp, int i, int j)
   if (data->Hertzian_sig > 0.0) tclprint_to_result_HertzianIA(interp,i,j);
 #endif
 
+#ifdef GAUSSIAN
+  if (data->Gaussian_cut > 0.0) tclprint_to_result_GaussianIA(interp,i,j);
+#endif
+
 #ifdef BMHTF_NACL
   if (data->BMHTF_cut > 0.0) tclprint_to_result_BMHTFIA(interp,i,j);
 #endif
@@ -411,6 +447,10 @@ int tclprint_to_result_NonbondedIA(Tcl_Interp *interp, int i, int j)
   if (data->soft_cut > 0.0) tclprint_to_result_softIA(interp,i,j);
 #endif
 
+#ifdef HAT
+  if (data->HAT_r > 0.0) tclprint_to_result_hatIA(interp,i,j);
+#endif
+
 #ifdef LJCOS2
   if (data->LJCOS2_cut > 0.0) tclprint_to_result_ljcos2IA(interp,i,j);
 #endif
@@ -536,7 +576,9 @@ int tclcommand_inter_print_all(Tcl_Interp *interp)
       else
 	Tcl_AppendResult(interp, " {", (char *)NULL);
 
-      tclprint_to_result_BondedIA(interp, i);
+      if (tclprint_to_result_BondedIA(interp, i) == TCL_ERROR) {
+        return TCL_ERROR;
+      }
       Tcl_AppendResult(interp, "}", (char *)NULL);
     }
   }
@@ -549,7 +591,9 @@ int tclcommand_inter_print_all(Tcl_Interp *interp)
 	}
 	else
 	  Tcl_AppendResult(interp, " {", (char *)NULL);
-	tclprint_to_result_NonbondedIA(interp, i, j);
+	if (tclprint_to_result_NonbondedIA(interp, i, j) == TCL_ERROR) {
+          return TCL_ERROR;
+        }
 	Tcl_AppendResult(interp, "}", (char *)NULL);
       }
     }
@@ -577,9 +621,7 @@ int tclcommand_inter_print_all(Tcl_Interp *interp)
   }
 #endif
 
-#ifdef LENNARD_JONES
-
-  if(lj_force_cap != 0.0) {
+  if(force_cap != 0.0) {
     char buffer[TCL_DOUBLE_SPACE];
     
     if (start) {
@@ -588,97 +630,15 @@ int tclcommand_inter_print_all(Tcl_Interp *interp)
     }
     else
       Tcl_AppendResult(interp, " {", (char *)NULL);
-    if (lj_force_cap == -1.0)
-      Tcl_AppendResult(interp, "ljforcecap individual", (char *)NULL);
+    if (force_cap == -1.0)
+      Tcl_AppendResult(interp, "forcecap individual", (char *)NULL);
     else {
-      Tcl_PrintDouble(interp, lj_force_cap, buffer);
-      Tcl_AppendResult(interp, "ljforcecap ", buffer, (char *) NULL);
+      Tcl_PrintDouble(interp, force_cap, buffer);
+      Tcl_AppendResult(interp, "forcecap ", buffer, (char *) NULL);
     }
     Tcl_AppendResult(interp, "}", (char *)NULL);
   }
 
-#endif
-
-#ifdef LJ_ANGLE
-  if(ljangle_force_cap != 0.0) {
-    char buffer[TCL_DOUBLE_SPACE];
-    
-    if (start) {
-      Tcl_AppendResult(interp, "{", (char *)NULL);
-      start = 0;
-    }
-    else
-      Tcl_AppendResult(interp, " {", (char *)NULL);
-    if (ljangle_force_cap == -1.0)
-      Tcl_AppendResult(interp, "ljangleforcecap individual", (char *)NULL);
-    else {
-      Tcl_PrintDouble(interp, ljangle_force_cap, buffer);
-      Tcl_AppendResult(interp, "ljangleforcecap ", buffer, (char *) NULL);
-    }
-    Tcl_AppendResult(interp, "}", (char *)NULL);
-  }
-#endif
-
-#ifdef MORSE
-if(morse_force_cap != 0.0) {
-    char buffer[TCL_DOUBLE_SPACE];
-
-    if (start) {
-      Tcl_AppendResult(interp, "{", (char *)NULL);
-      start = 0;
-    }
-    else
-      Tcl_AppendResult(interp, " {", (char *)NULL);
-    if (morse_force_cap == -1.0)
-      Tcl_AppendResult(interp, "morseforcecap individual", (char *)NULL);
-    else {
-      Tcl_PrintDouble(interp, morse_force_cap, buffer);
-      Tcl_AppendResult(interp, "morseforcecap ", buffer, (char *) NULL);
-    }
-    Tcl_AppendResult(interp, "}", (char *)NULL);
-  }
-#endif
-
-#ifdef BUCKINGHAM 
-  if(buck_force_cap != 0.0) {
-    char buffer[TCL_DOUBLE_SPACE];
-    
-    if (start) {
-      Tcl_AppendResult(interp, "{", (char *)NULL);
-      start = 0;
-    }
-    else
-      Tcl_AppendResult(interp, " {", (char *)NULL);
-
-    if (lj_force_cap == -1.0)
-      Tcl_AppendResult(interp, "buckforcecap individual", (char *)NULL);
-    else {
-      Tcl_PrintDouble(interp, buck_force_cap, buffer);
-      Tcl_AppendResult(interp, "buckforcecap ", buffer, (char *) NULL);
-    }
-    Tcl_AppendResult(interp, "}", (char *)NULL);
-  }
-#endif
-
-#ifdef TABULATED
-  if(tab_force_cap != 0.0) {
-    char buffer[TCL_DOUBLE_SPACE];
-    if (start) {
-      Tcl_AppendResult(interp, "{", (char *)NULL);
-      start = 0;
-    }
-    else
-      Tcl_AppendResult(interp, " {", (char *)NULL);
-    if (tab_force_cap == -1.0)
-      Tcl_AppendResult(interp, "tabforcecap individual", (char *)NULL);
-    else {
-      Tcl_PrintDouble(interp, tab_force_cap, buffer);
-      Tcl_AppendResult(interp, "tabforcecap ", buffer, (char *) NULL);
-    }
-    Tcl_AppendResult(interp, "}", (char *)NULL);
-  }
-#endif
-
   return (TCL_OK);
 }
 
@@ -732,12 +692,12 @@ int tclcommand_inter_print_non_bonded(Tcl_Interp * interp,
 /* TODO: This function is not used anywhere. To be removed?  */
 int tf_print(Tcl_Interp * interp, int part_type)
 {
-  TF_parameters *data;
+  //TF_parameters *data;
   Tcl_ResetResult(interp);
     
     make_particle_type_exist(part_type);
     
-    data = get_tf_param(part_type);
+    //data = get_tf_param(part_type);
     
     return tclprint_to_result_TF(interp, part_type);
 }
@@ -794,6 +754,10 @@ int tclcommand_inter_parse_non_bonded(Tcl_Interp * interp,
     REGISTER_NONBONDED("hertzian", tclcommand_inter_parse_hertzian);
 #endif
 
+#ifdef GAUSSIAN
+    REGISTER_NONBONDED("gaussian", tclcommand_inter_parse_gaussian);
+#endif
+
 #ifdef BMHTF_NACL
     REGISTER_NONBONDED("bmhtf-nacl", tclcommand_inter_parse_BMHTF);
 #endif
@@ -814,6 +778,10 @@ int tclcommand_inter_parse_non_bonded(Tcl_Interp * interp,
     REGISTER_NONBONDED("soft-sphere", tclcommand_inter_parse_soft);
 #endif
 
+#ifdef HAT
+    REGISTER_NONBONDED("hat", tclcommand_inter_parse_hat);
+#endif
+
 #ifdef COMFORCE
     REGISTER_NONBONDED("comforce", tclcommand_inter_parse_comforce);
 #endif
@@ -920,13 +888,27 @@ int tclcommand_inter_parse_bonded(Tcl_Interp *interp,
   if (ARG0_IS_S(name)) return parser(interp, bond_type, argc, argv);
   
   REGISTER_BONDED("fene", tclcommand_inter_parse_fene);
+  REGISTER_BONDED("stretching_force", tclcommand_inter_parse_stretching_force);
+  REGISTER_BONDED("area_force_local", tclcommand_inter_parse_area_force_local);
+  REGISTER_BONDED("bending_force", tclcommand_inter_parse_bending_force);
+#ifdef AREA_FORCE_GLOBAL
+  REGISTER_BONDED("area_force_global", tclcommand_inter_parse_area_force_global);
+#endif
+#ifdef VOLUME_FORCE
+  REGISTER_BONDED("volume_force", tclcommand_inter_parse_volume_force);
+#endif
   REGISTER_BONDED("harmonic", tclcommand_inter_parse_harmonic);
 #ifdef LENNARD_JONES  
   REGISTER_BONDED("subt_lj", tclcommand_inter_parse_subt_lj);
 #endif
-#ifdef BOND_ANGLE
+#ifdef BOND_ANGLE_OLD
   REGISTER_BONDED("angle", tclcommand_inter_parse_angle);
 #endif
+#ifdef BOND_ANGLE
+  REGISTER_BONDED("angle_harmonic", tclcommand_inter_parse_angle_harmonic);
+  REGISTER_BONDED("angle_cosine", tclcommand_inter_parse_angle_cosine);
+  REGISTER_BONDED("angle_cossquare", tclcommand_inter_parse_angle_cossquare);
+#endif
 #ifdef BOND_ANGLEDIST
   REGISTER_BONDED("angledist", tclcommand_inter_parse_angledist);
 #endif
@@ -953,6 +935,9 @@ int tclcommand_inter_parse_bonded(Tcl_Interp *interp,
 
 int tclcommand_inter_parse_rest(Tcl_Interp * interp, int argc, char ** argv)
 {
+  if(ARG0_IS_S("forcecap"))
+    return tclcommand_inter_parse_forcecap(interp,argc-1, argv+1);
+
 #if defined(LENNARD_JONES) || defined(LENNARD_JONES_GENERIC)
   if(ARG0_IS_S("ljforcecap"))
     return tclcommand_inter_parse_ljforcecap(interp, argc-1, argv+1);
@@ -1058,7 +1043,7 @@ int tclcommand_inter(ClientData _data, Tcl_Interp *interp,
     is_i2 = ARG_IS_I(2, j);
 
     Tcl_ResetResult(interp);
- 
+
     // non bonded interactions
     if (is_i1 && is_i2)
       err_code = tclcommand_inter_parse_non_bonded(interp, i, j, argc-3, argv+3);
