@@ -30,10 +30,11 @@
 #include "morse.h"
 #include "interaction_data.h"
 #include "parser.h"
+#include "forcecap_tcl.h"
 
 int tclprint_to_result_morseIA(Tcl_Interp *interp, int i, int j)
 {
-  char buffer[TCL_DOUBLE_SPACE];
+    char buffer[TCL_DOUBLE_SPACE];
   IA_parameters *data = get_ia_param(i, j);
 
   Tcl_PrintDouble(interp, data->MORSE_eps, buffer);
@@ -53,35 +54,12 @@ int tclprint_to_result_morseIA(Tcl_Interp *interp, int i, int j)
 /// parser for the forcecap
 int tclcommand_inter_parse_morseforcecap(Tcl_Interp * interp, int argc, char ** argv)
 {
-  char buffer[TCL_DOUBLE_SPACE];
-
-  if (argc == 0) {
-    if (morse_force_cap == -1.0)
-      Tcl_AppendResult(interp, "morseforcecap individual", (char *) NULL);
-    else {
-      Tcl_PrintDouble(interp, morse_force_cap, buffer);
-      Tcl_AppendResult(interp, "morseforcecap ", buffer, (char *) NULL);
-    }
-    return TCL_OK;
+  if (argc==1) {
+    fprintf(stderr, "WARNING: \"inter morseforcecap\" is deprecated "
+	    "and will be removed in some further version. "
+	    "Use \"inter forcecap\" instead.\n");
   }
-
-  if (argc > 1) {
-    Tcl_AppendResult(interp, "inter morseforcecap takes at most 1 parameter",
-		     (char *) NULL);      
-    return TCL_ERROR;
-  }
-  
-  if (ARG0_IS_S("individual"))
-      morse_force_cap = -1.0;
-  else if (! ARG0_IS_D(morse_force_cap) || morse_force_cap < 0) {
-    Tcl_ResetResult(interp);
-    Tcl_AppendResult(interp, "force cap must be a nonnegative double value or \"individual\"",
-		     (char *) NULL);
-    return TCL_ERROR;
-  }
-
-  CHECK_VALUE(morseforcecap_set_params(morse_force_cap),
-	      "If you can read this, you should change it. (Use the source Luke!)");
+  return tclcommand_inter_parse_forcecap(interp, argc, argv);
 }
 
 
