@@ -422,6 +422,16 @@ MDINLINE void vecsub(double v1[3], double v2[3], double dv[3])
 }
 
 
+/** calculates the length of a vector */
+MDINLINE double normr(double v[3]) {
+  double d2 = 0.0;
+  int i;
+  for(i=0;i<3;i++)
+    d2 += SQR(v[i]);
+  d2 = sqrtf(d2);
+  return d2;
+}
+
 /** calculates the squared length of a vector */
 MDINLINE double sqrlen(double v[3]) {
   double d2 = 0.0;
@@ -922,4 +932,116 @@ MDINLINE char *strcat_alloc(char *left, char *right)
 
 /*@}*/
 
+/*************************************************************/
+/** \name Object-in-fluid functions                          */
+/*************************************************************/
+/*@{*/
+
+/** Computes the area of triangle between vectors P1 and P2, 
+ *  by computing the crossproduct P1 x P2 and taking the half of its norm */
+MDINLINE double area_triangle_new(double *P1, double *P2) {
+ double area;
+ double normal[3], n; //auxiliary variables
+ vector_product(P1,P2,normal); 
+ n=normr(normal);
+ area = 0.5*n;
+ return area;
+}
+
+/** Computes the area of triangle between vectors P1,P2,P3, 
+ *  by computing the crossproduct P1P2 x P1P3 and taking the half of its norm */
+MDINLINE double area_triangle(double *P1, double *P2, double *P3) {
+	double area;
+	double u[3],v[3],normal[3], n; //auxiliary variables
+	u[0] = P2[0] - P1[0]; // u = P1P2
+	u[1] = P2[1] - P1[1]; 
+	u[2] = P2[2] - P1[2]; 
+	v[0] = P3[0] - P1[0]; // v = P1P3
+	v[1] = P3[1] - P1[1]; 
+	v[2] = P3[2] - P1[2]; 
+	vector_product(u,v,normal); 
+	n=normr(normal);
+	area = 0.5*n;
+	return area;
+}
+
+/** Computes the normal vector to the plane given by points P1P2P3 */
+MDINLINE void get_n_triangle(double* p1, double* p2, double* p3, double* n){
+	n[0]=(p2[1]-p1[1])*(p3[2]-p1[2])-(p2[2]-p1[2])*(p3[1]-p1[1]);
+	n[1]=(p2[2]-p1[2])*(p3[0]-p1[0])-(p2[0]-p1[0])*(p3[2]-p1[2]);
+	n[2]=(p2[0]-p1[0])*(p3[1]-p1[1])-(p2[1]-p1[1])*(p3[0]-p1[0]);
+}
+
+/** This function returns the angle btw the triangle p1,p2,p3 and p2,p3,p4. 
+ *  Be careful, the angle depends on the orientation of the trianlges! 
+ *  You need to be sure that the orientation (direction of normal vector) 
+ *  of p1p2p3 is given by the cross product p2p1 x p2p3. 
+ *  The orientation of p2p3p4 must be given by p2p3 x p2p4. 
+ * 
+ *  Example: p1 = (0,0,1), p2 = (0,0,0), p3=(1,0,0), p4=(0,1,0). 
+ *  The orientation of p1p2p3 should be in the direction (0,1,0) 
+ *  and indeed: p2p1 x p2p3 = (0,0,1)x(1,0,0) = (0,1,0)
+ *  This function is called in the beginning of the simulation when creating 
+ *  bonds depending on the angle btw the triangles, the bending_force.
+ *  Here, we determine the orientations by looping over the triangles 
+ *  and checking the correct orientation. So when defining the bonds by tcl command
+ *  "part p2 bond xxxx p1 p3 p4", we correctly input the particle id's.
+ *  So if you have the access to the order of particles, you are safe to call this
+ *  function with exactly this order. Otherwise you need to check the orientations. */
+MDINLINE double angle_btw_triangles(double *P1, double *P2, double *P3, double *P4) {
+	double phi;
+	double u[3],v[3],normal1[3],normal2[3]; //auxiliary variables
+	u[0] = P1[0] - P2[0]; // u = P2P1
+	u[1] = P1[1] - P2[1]; 
+	u[2] = P1[2] - P2[2]; 
+	v[0] = P3[0] - P2[0]; // v = P2P3
+	v[1] = P3[1] - P2[1]; 
+	v[2] = P3[2] - P2[2]; 
+	vector_product(u,v,normal1); 
+	u[0] = P3[0] - P2[0]; // u = P2P3
+	u[1] = P3[1] - P2[1]; 
+	u[2] = P3[2] - P2[2]; 
+	v[0] = P4[0] - P2[0]; // v = P2P4
+	v[1] = P4[1] - P2[1]; 
+	v[2] = P4[2] - P2[2]; 
+	vector_product(u,v,normal2); 
+
+	double tmp11,tmp22,tmp33;
+	// Now we compute the scalar product of n1 and n2 divided by the norms of n1 and n2
+	//tmp11 = dot(3,normal1,normal2);         // tmp11 = n1.n2
+	tmp11 = scalar(normal1,normal2);         // tmp11 = n1.n2
+	
+	/*	
+	tmp22 = normr(normal1);
+	tmp33 = normr(normal2);
+	tmp11 /= (tmp22*tmp33);  // tmp11 = n1.n2/(|n1||n2|)
+*/
+	tmp11 *= fabs(tmp11); // tmp11 = (n1.n2)^2
+	tmp22 = sqrlen(normal1);  //tmp22 = |n1|^2
+	tmp33 = sqrlen(normal2);  //tmp33 = |n1|^2
+	tmp11 /= (tmp22*tmp33);  // tmp11 = (n1.n2/(|n1||n2|))^2
+	if (tmp11 > 0 ) {
+		tmp11 = sqrt(tmp11);
+	} else {
+		tmp11 = - sqrt(- tmp11);
+	}		
+
+	if(tmp11>=1.) { tmp11=0.0;}
+	else if(tmp11<=-1.) { tmp11=M_PI;}
+	phi = M_PI - acos(tmp11); 	// The angle between the faces (not considering the orientation, always less or equal to Pi) is
+								// equal to Pi minus angle between the normals
+	
+	// Now we need to determine, if the angle btw two triangles is less than Pi or more than Pi. To do this we check, 
+	// if the point P4 lies in the halfspace given by trianlge P1P2P3 and the normal to this triangle. If yes, we have 
+	// angle less than Pi, if not, we have angle more than Pi.
+	// General equation of the plane is n_x*x + n_y*y + n_z*z + d = 0 where (n_x,n_y,n_z) is the normal to the plane.
+	// Point P1 lies in the plane, therefore d = -(n_x*P1_x + n_y*P1_y + n_z*P1_z)
+	// Point P4 lies in the halfspace given by normal iff n_x*P4_x + n_y*P4_y + n_z*P4_z + d >= 0
+	tmp11 = - (normal1[0]*P1[0] + normal1[1]*P1[1] + normal1[2]*P1[2]);
+	if (normal1[0]*P4[0] + normal1[1]*P4[1] + normal1[2]*P4[2] + tmp11 < 0) phi = 2*M_PI - phi;
+	return phi;
+}
+
+/*@}*/
+
 #endif
