@@ -21,8 +21,7 @@
 source "tests_common.tcl"
 
 require_feature "LENNARD_JONES"
-# MOL_CUT increases the short ranged radius so much that this test's box is too small
-require_feature "MOL_CUT" off
+require_feature "ADRESS" off
 
 puts "----------------------------------------"
 puts "- Testcase intpbc.tcl running on [format %02d [setmd n_nodes]] nodes: -"
@@ -145,4 +144,4 @@ if { [catch {
     error_exit $res
 }
 
-exit 0
\ No newline at end of file
+exit 0
