@@ -30,6 +30,7 @@ source "tests_common.tcl"
 
 require_feature "LB"
 require_feature "LENNARD_JONES"
+require_feature "ADRESS" off
 
 puts "----------------------------------------"
 puts "- Testcase lb.tcl running on [format %02d [setmd n_nodes]] nodes  -"
@@ -105,7 +106,7 @@ setmd periodic 1 1 1
 read_data "lb_system.data"
 thermostat langevin 1. 1.
 integrate 1000
-stop_particles
+kill_particle_motion
 thermostat off
 #part 0 pos 10 10 10
 # here you can create the necessary snapshot
