@@ -22,6 +22,8 @@ source "tests_common.tcl"
 require_feature "NPT"
 require_feature "LENNARD_JONES"
 require_feature "ADRESS" off
+# incompatible with NPT
+require_feature "ROTATION_PER_PARTICLE" off
 
 puts "----------------------------------------"
 puts "- Testcase npt.tcl running on [format %02d [setmd n_nodes]] nodes: -"
