@@ -24,7 +24,7 @@ source "tests_common.tcl"
 require_feature "LENNARD_JONES"
 require_feature "ELECTROSTATICS"
 require_feature "FFTW"
-require_feature "MOL_CUT" off
+require_feature "ADRESS" off
 
 puts "---------------------------------------------------------------"
 puts "- Testcase p3m.tcl running on [format %02d [setmd n_nodes]] nodes"
