@@ -394,7 +394,7 @@ if { $vmd_output=="yes" } {
 #puts "\nStart warmup integration: max $warm_n_times times $warm_steps steps\n"
 set act_min_dist [analyze mindist]
 set cap 20  
-inter ljforcecap $cap
+inter forcecap $cap
 
 for {set xi 0} { $xi < $warm_n_times  && $act_min_dist < $min_dist } { incr xi} {
     puts -nonewline "Run $xi at time=[setmd time] min_dist=$act_min_dist\r"
@@ -403,7 +403,7 @@ for {set xi 0} { $xi < $warm_n_times  && $act_min_dist < $min_dist } { incr xi}
     if { $vmd_output=="yes" } {catch { imd positions }}
     set act_min_dist [analyze mindist]
     set cap [expr $cap+10]
-    inter ljforcecap $cap  
+    inter forcecap $cap  
 }
 
 #puts "Warmup done: Minimal distance [analyze mindist]\n"
@@ -414,7 +414,7 @@ for {set xi 0} { $xi < $warm_n_times  && $act_min_dist < $min_dist } { incr xi}
 
 #puts "Start Counterion Equilibration: $ci_n_times times $ci_steps steps\n"
 # remove LJ cap
-inter ljforcecap 0
+inter forcecap 0
 # Start Coulomb interaction
 inter coulomb $bjerrum dh 0.0 [expr 2.0*$sphere_rad]
 
@@ -476,7 +476,7 @@ inter 1 4 lennard-jones 0.0 1.0 0.0 0.25 0 0
 
 
 #reset the forces and velovities for all the particles.
-stop_particles
+kill_particle_motion
 
 analyze set chains 0 $n_poly $p_length
 #puts "Interactions:\n [inter]"
